@@ -6,10 +6,10 @@
 #' @param path_out path directory to export the output, if it has a value the plot is saved,
 #' if the directory doesn't existis it will try to create it. To save in current directory path must be dot: "."
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' plot_num(mtcars)
 #' # changing the bins parameter and exporting the plot
-#' # plot_num(data=mtcars, bins=5, path_out="my_folder")
+#' plot_num(data=mtcars, bins=5, path_out="my_folder")
 #' }
 #' @return plot containing all numerical variables
 #' @export
@@ -367,13 +367,13 @@ freq_logic <- function(data, input, plot, na.rm, path_out)
 					axis.title.y=element_text(size=14, margin=margin(0,10,0,0))
 				) + ylab("Frequency / (Percentage %)") + xlab(input) +
 				geom_text( color="#151515", size=letter_size, hjust=-.06) +
-				guides(fill=F) +
+				guides(fill="none") +
 			scale_y_continuous(expand = c(0,0), limits = c(0, max(tbl_plot$frequency)*1.5))
 
 			## Save plot
 			if(!is.na(path_out))
 			{
-				dir.create(path_out, showWarnings = FALSE)
+				dir.create(path_out, showWarnings = F)
 
 				if(dir.exists(path_out))
 				{
