@@ -5,7 +5,7 @@
 #' @param input numeric/character vector
 #' @param target numeric/character vector
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # Measuring entropy between input and target variable
 #' entropy_2(input=data_golf$outlook, target=data_golf$play_golf)
 #' }
@@ -23,7 +23,7 @@ entropy_2 <- function(input, target)
 
 	# get partial entropy
 	df_tbl=as.data.frame.matrix(tbl)
-	res_entropy=data.frame(t(df_tbl)) %>% mutate_all(funs(entropy(., unit = "log2"))) %>% head(.,1)
+	res_entropy=data.frame(t(df_tbl)) %>% mutate(across(everything(), ~entropy(., unit = "log2"))) %>% head(.,1)
 
 	# computing total entropy
 	total_en=sum(probs_input*res_entropy)
@@ -36,7 +36,7 @@ entropy_2 <- function(input, target)
 #' @param input numeric/character vector
 #' @param target numeric/character vector
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' information_gain(input=data_golf$outlook, target=data_golf$play_golf)
 #' }
 #' @return information gain
@@ -56,7 +56,7 @@ information_gain <- function(input, target)
 #' @param input numeric/character vector
 #' @param target numeric/character vector
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' gain_ratio(input=data_golf$outlook, target=data_golf$play_golf)
 #' }
 #' @return gain ratio
@@ -78,7 +78,7 @@ gain_ratio <- function(input, target)
 #' @param data input data frame, all the variables will be evaluated against the variable defined in 'target' parameter
 #' @param target string variable name containing the output variable.
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' var_rank_info(data_golf, "play_golf")
 #' }
 #' @return data frame ordered by gain ratio metric
@@ -88,7 +88,7 @@ var_rank_info <- function(data, target)
 	nam=colnames(data)
 	nam=nam[nam!=target]
 
-	df_res=data.frame(var=NULL, en=NULL, mi=NULL, ig=NULL, gr=NULL, stringsAsFactors = FALSE)
+	df_res=data.frame(var=NULL, en=NULL, mi=NULL, ig=NULL, gr=NULL, stringsAsFactors = F)
 
 	for(var in nam)
 	{
@@ -110,7 +110,7 @@ var_rank_info <- function(data, target)
 #' @param input vector to be evaluated against the variable defined in 'target' parameter
 #' @param target vector containing the output variable.
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' infor_magic(data_golf$outlook, data_golf$play_golf)
 #' }
 #' @return Matrix of 1 row and 4 columns, where each column represent the mentioned metrics
